@@ -138,6 +138,8 @@ private slots:
     //! Invoked when user invokes refresh
     void onRefresh ();
     void onRefreshAll ();
+    void onSigRefreshContacts();
+    void onSigRefreshInbox();
 
     //! Status messages timeout
     void onStatusTimerTick ();
@@ -146,15 +148,20 @@ private slots:
     void onSigProxyChanges(bool bEnable, bool bUseSystemProxy,
                            const QString &host, int port, bool bRequiresAuth,
                            const QString &user, const QString &pass);
+    //! Activated when the user clicks cancel on proxy changes
+    void onSigProxyRefresh(bool bSet = false);
+
     //! Activated when a link is clicked in the QML
     void onLinkActivated (const QString &strLink);
 
     //! Activated when the user saves the mosquitto settings
     void onSigMosquittoChanges(bool bEnable, const QString &host, int port,
                                const QString &topic);
+    void refreshMqSettings(bool bForceShut = false);
 
     //! Activated when the user saves the GV pin
     void onSigPinSettingChanges(bool bEnable, const QString &pin);
+    void refreshPinSettings();
 
     void onMqThreadFinished();
 
@@ -222,9 +229,6 @@ private:
 
     void fallbackDialout (DialContext *ctx);
 
-    void setMqSettingsInQml(bool bEnable, const QString &host, int port,
-                            const QString &topic);
-
     void clearSmsDestinations();
 
     void createVmailPlayer();
